package com.actionbazaar.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import javax.ws.rs.core.MediaType;

import org.jboss.arquillian.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.actionbazaar.dao.BidDao;
import com.actionbazaar.dao.DefaultBidDao;
import com.actionbazaar.domain.Bid;
import com.actionbazaar.service.BidRestService;
import com.actionbazaar.service.BidService;
import com.actionbazaar.service.DefaultBidService;
import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.WebResource;

@RunWith(Arquillian.class)
public class BidRestServiceTest {

	@Deployment
	public static WebArchive createDeployment() {
		return ShrinkWrap
				.create(WebArchive.class, "test.war")
				.addClasses(BidRestService.class, BidService.class,
						DefaultBidService.class, BidDao.class,
						DefaultBidDao.class, Bid.class)
				.addWebResource(EmptyAsset.INSTANCE, "beans.xml")
				.addWebResource("test-persistence.xml",
						"classes/META-INF/persistence.xml")
				.setWebXML("rest-test-web.xml");
	}

	@Test
	public void testAddBid() {
		Client client = Client.create();
		WebResource resource = client
				.resource("http://localhost:7070/test/rest/bid");

		Bid bid = new Bid();
		bid.setAmount(10.0);
		bid.setBidder("New Bidder");
		bid.setItem("New Item");

		resource.type(MediaType.TEXT_XML_TYPE).post(bid);

		bid = null;

		bid = resource.queryParam("id", "1").accept(MediaType.TEXT_XML_TYPE)
				.get(Bid.class);

		assertNotNull(bid);
		assertEquals(bid.getId(), new Long(1));
		assertEquals(bid.getAmount(), new Double(10.0));
		assertEquals(bid.getBidder(), "New Bidder");
		assertEquals(bid.getItem(), "New Item");
	}
}