package com.actionbazaar.test;

import static org.junit.Assert.assertNotNull;

import javax.ejb.EJB;

import org.jboss.arquillian.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.actionbazaar.dao.BidDao;
import com.actionbazaar.dao.DefaultBidDao;
import com.actionbazaar.domain.Bid;
import com.actionbazaar.service.BidService;
import com.actionbazaar.service.DefaultBidService;

@RunWith(Arquillian.class)
public class BidServiceTest {

	@Deployment
	public static WebArchive createDeployment() {
		return ShrinkWrap
				.create(WebArchive.class, "test.war")
				.addClasses(BidService.class, DefaultBidService.class,
						BidDao.class, DefaultBidDao.class, Bid.class)
				.addWebResource(EmptyAsset.INSTANCE, "beans.xml")
				.addWebResource("test-persistence.xml",
						"classes/META-INF/persistence.xml");
	}

	@EJB
	private BidService bidService;

	@Test
	public void testAddBid() {
		Bid bid = new Bid();
		bid.setBidder("rrahman");
		bid.setItem("Test item");
		bid.setAmount(100.50);

		bidService.addBid(bid);
	}

	@Test
	public void testGetBid() {
		Bid bid = bidService.getBid(1L);
		assertNotNull(bid);
	}

	@Test
	public void testUpdateBid() {
		Bid bid = bidService.getBid(1L);
		bid.setAmount(101.50);
		bidService.updateBid(bid);
	}

	@Test
	public void testDeleteBid() {
		Bid bid = bidService.getBid(1L);
		bidService.deleteBid(bid);
	}
}
